@@ -14,11 +14,9 @@ pub(super) static ATTR_ENDPOINT: &str = "endpoint";
 pub(super) static ATTR_CALLBACK_DECL: &str = "callback";
 pub(super) static ATTR_CALLBACK_RAW_DECL: &str = "callback_raw";
 pub(super) static ATTR_CALLBACK_CALL_RESULT: &str = "call_result";
-pub(super) static ATTR_MULTI: &str = "multi";
 pub(super) static ATTR_STORAGE_GET: &str = "storage_get";
 pub(super) static ATTR_STORAGE_SET: &str = "storage_set";
 pub(super) static ATTR_STORAGE_MAPPER: &str = "storage_mapper";
 pub(super) static ATTR_STORAGE_IS_EMPTY: &str = "storage_is_empty";
 pub(super) static ATTR_STORAGE_CLEAR: &str = "storage_clear";
-pub(super) static ATTR_MODULE: &str = "module";
 pub(super) static ATTR_PROXY: &str = "proxy";
