@@ -1,36 +1,22 @@
 use super::attr_names::*;
-use super::util::*;
-
-static EGLD_DEFAULT: &str = "EGLD";
-
-pub fn is_payment_amount(pat: &syn::PatType) -> bool {
-	has_attribute(&pat.attrs, ATTR_PAYMENT_AMOUNT) || has_attribute(&pat.attrs, ATTR_PAYMENT)
-}
-
-pub fn is_payment_token(pat: &syn::PatType) -> bool {
-	has_attribute(&pat.attrs, ATTR_PAYMENT_TOKEN)
-}
-
-pub fn is_payment_nonce(pat: &syn::PatType) -> bool {
-	has_attribute(&pat.attrs, ATTR_PAYMENT_NONCE)
-}
 
 pub struct PayableAttribute {
 	pub identifier: Option<String>,
 }
 
 impl PayableAttribute {
-	pub fn parse(m: &syn::TraitItemMethod) -> Option<PayableAttribute> {
-		let payable_attr = m.attrs.iter().find(|attr| {
-			if let Some(first_seg) = attr.path.segments.first() {
-				first_seg.ident == ATTR_PAYABLE
+	pub fn parse(attr: &syn::Attribute) -> Option<PayableAttribute> {
+		if let Some(first_seg) = attr.path.segments.first() {
+			if first_seg.ident == ATTR_PAYABLE {
+				Some(PayableAttribute {
+					identifier: extract_token_identifier(attr),
+				})
 			} else {
-				false
+				None
 			}
-		});
-		payable_attr.map(|attr| PayableAttribute {
-			identifier: extract_token_identifier(attr),
-		})
+		} else {
+			None
+		}
 	}
 }
 
